==> credentials-binding-1.13-sources.jar: org/jenkinsci/plugins/credentialsbinding/impl/Messages.java <==
// CHECKSTYLE:OFF

package org.jenkinsci.plugins.credentialsbinding.impl;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code ZipFileBinding.NotZipFile}: {@code Not a ZIP file}.
     * 
     * @return
     *     {@code Not a ZIP file}
     */
    public static String ZipFileBinding_NotZipFile() {
        return holder.format("ZipFileBinding.NotZipFile");
    }

    /**
     * Key {@code ZipFileBinding.NotZipFile}: {@code Not a ZIP file}.
     * 
     * @return
     *     {@code Not a ZIP file}
     */
    public static Localizable _ZipFileBinding_NotZipFile() {
        return new Localizable(holder, "ZipFileBinding.NotZipFile");
    }

    /**
     * Key {@code UsernamePasswordMultiBinding.username_and_password}: {@code
     * Username and password (separated)}.
     * 
     * @return
     *     {@code Username and password (separated)}
     */
    public static String UsernamePasswordMultiBinding_username_and_password() {
        return holder.format("UsernamePasswordMultiBinding.username_and_password");
    }

    /**
     * Key {@code UsernamePasswordMultiBinding.username_and_password}: {@code
     * Username and password (separated)}.
     * 
     * @return
     *     {@code Username and password (separated)}
     */
    public static Localizable _UsernamePasswordMultiBinding_username_and_password() {
        return new Localizable(holder, "UsernamePasswordMultiBinding.username_and_password");
    }

    /**
     * Key {@code FileBinding.secret_file}: {@code Secret file}.
     * 
     * @return
     *     {@code Secret file}
     */
    public static String FileBinding_secret_file() {
        return holder.format("FileBinding.secret_file");
    }

    /**
     * Key {@code FileBinding.secret_file}: {@code Secret file}.
     * 
     * @return
     *     {@code Secret file}
     */
    public static Localizable _FileBinding_secret_file() {
        return new Localizable(holder, "FileBinding.secret_file");
    }

    /**
     * Key {@code ZipFileBinding.secret_zip_file}: {@code Secret ZIP file}.
     * 
     * @return
     *     {@code Secret ZIP file}
     */
    public static String ZipFileBinding_secret_zip_file() {
        return holder.format("ZipFileBinding.secret_zip_file");
    }

    /**
     * Key {@code ZipFileBinding.secret_zip_file}: {@code Secret ZIP file}.
     * 
     * @return
     *     {@code Secret ZIP file}
     */
    public static Localizable _ZipFileBinding_secret_zip_file() {
        return new Localizable(holder, "ZipFileBinding.secret_zip_file");
    }

    /**
     * Key {@code SSHUserPrivateKeyBinding.ssh_user_private_key}: {@code SSH
     * User Private Key}.
     * 
     * @return
     *     {@code SSH User Private Key}
     */
    public static String SSHUserPrivateKeyBinding_ssh_user_private_key() {
        return holder.format("SSHUserPrivateKeyBinding.ssh_user_private_key");
    }

    /**
     * Key {@code SSHUserPrivateKeyBinding.ssh_user_private_key}: {@code SSH
     * User Private Key}.
     * 
     * @return
     *     {@code SSH User Private Key}
     */
    public static Localizable _SSHUserPrivateKeyBinding_ssh_user_private_key() {
        return new Localizable(holder, "SSHUserPrivateKeyBinding.ssh_user_private_key");
    }

    /**
     * Key {@code UsernamePasswordBinding.username_and_password}: {@code
     * Username and password (conjoined)}.
     * 
     * @return
     *     {@code Username and password (conjoined)}
     */
    public static String UsernamePasswordBinding_username_and_password() {
        return holder.format("UsernamePasswordBinding.username_and_password");
    }

    /**
     * Key {@code UsernamePasswordBinding.username_and_password}: {@code
     * Username and password (conjoined)}.
     * 
     * @return
     *     {@code Username and password (conjoined)}
     */
    public static Localizable _UsernamePasswordBinding_username_and_password() {
        return new Localizable(holder, "UsernamePasswordBinding.username_and_password");
    }

    /**
     * Key {@code CertificateMultiBinding.certificate_keystore}: {@code
     * Certificate}.
     * 
     * @return
     *     {@code Certificate}
     */
    public static String CertificateMultiBinding_certificate_keystore() {
        return holder.format("CertificateMultiBinding.certificate_keystore");
    }

    /**
     * Key {@code CertificateMultiBinding.certificate_keystore}: {@code
     * Certificate}.
     * 
     * @return
     *     {@code Certificate}
     */
    public static Localizable _CertificateMultiBinding_certificate_keystore() {
        return new Localizable(holder, "CertificateMultiBinding.certificate_keystore");
    }

    /**
     * Key {@code SecretBuildWrapper.use_secret_text_s_or_file_s_}: {@code
     * Use secret text(s) or file(s)}.
     * 
     * @return
     *     {@code Use secret text(s) or file(s)}
     */
    public static String SecretBuildWrapper_use_secret_text_s_or_file_s_() {
        return holder.format("SecretBuildWrapper.use_secret_text_s_or_file_s_");
    }

    /**
     * Key {@code SecretBuildWrapper.use_secret_text_s_or_file_s_}: {@code
     * Use secret text(s) or file(s)}.
     * 
     * @return
     *     {@code Use secret text(s) or file(s)}
     */
    public static Localizable _SecretBuildWrapper_use_secret_text_s_or_file_s_() {
        return new Localizable(holder, "SecretBuildWrapper.use_secret_text_s_or_file_s_");
    }

    /**
     * Key {@code StringBinding.secret_text}: {@code Secret text}.
     * 
     * @return
     *     {@code Secret text}
     */
    public static String StringBinding_secret_text() {
        return holder.format("StringBinding.secret_text");
    }

    /**
     * Key {@code StringBinding.secret_text}: {@code Secret text}.
     * 
     * @return
     *     {@code Secret text}
     */
    public static Localizable _StringBinding_secret_text() {
        return new Localizable(holder, "StringBinding.secret_text");
    }

    /**
     * Key {@code ZipFileBinding.NoSuchCredentials}: {@code No such
     * credentials}.
     * 
     * @return
     *     {@code No such credentials}
     */
    public static String ZipFileBinding_NoSuchCredentials() {
        return holder.format("ZipFileBinding.NoSuchCredentials");
    }

    /**
     * Key {@code ZipFileBinding.NoSuchCredentials}: {@code No such
     * credentials}.
     * 
     * @return
     *     {@code No such credentials}
     */
    public static Localizable _ZipFileBinding_NoSuchCredentials() {
        return new Localizable(holder, "ZipFileBinding.NoSuchCredentials");
    }

    /**
     * Key {@code ZipFileBinding.CouldNotVerifyFileFormat}: {@code Could not
     * verify file format}.
     * 
     * @return
     *     {@code Could not verify file format}
     */
    public static String ZipFileBinding_CouldNotVerifyFileFormat() {
        return holder.format("ZipFileBinding.CouldNotVerifyFileFormat");
    }

    /**
     * Key {@code ZipFileBinding.CouldNotVerifyFileFormat}: {@code Could not
     * verify file format}.
     * 
     * @return
     *     {@code Could not verify file format}
     */
    public static Localizable _ZipFileBinding_CouldNotVerifyFileFormat() {
        return new Localizable(holder, "ZipFileBinding.CouldNotVerifyFileFormat");
    }

}

==> credentials-binding-1.25-sources.jar: org/jenkinsci/plugins/credentialsbinding/impl/Messages.java <==
// CHECKSTYLE:OFF

package org.jenkinsci.plugins.credentialsbinding.impl;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;
import org.kohsuke.accmod.Restricted;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
@Restricted(org.kohsuke.accmod.restrictions.NoExternalUse.class)
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code ZipFileBinding.NotZipFile}: {@code Not a ZIP file}.
     * 
     * @return
     *     {@code Not a ZIP file}
     */
    public static String ZipFileBinding_NotZipFile() {
        return holder.format("ZipFileBinding.NotZipFile");
    }

    /**
     * Key {@code ZipFileBinding.NotZipFile}: {@code Not a ZIP file}.
     * 
     * @return
     *     {@code Not a ZIP file}
     */
    public static Localizable _ZipFileBinding_NotZipFile() {
        return new Localizable(holder, "ZipFileBinding.NotZipFile");
    }

    /**
     * Key {@code UsernamePasswordMultiBinding.username_and_password}: {@code
     * Username and password (separated)}.
     * 
     * @return
     *     {@code Username and password (separated)}
     */
    public static String UsernamePasswordMultiBinding_username_and_password() {
        return holder.format("UsernamePasswordMultiBinding.username_and_password");
    }

    /**
     * Key {@code UsernamePasswordMultiBinding.username_and_password}: {@code
     * Username and password (separated)}.
     * 
     * @return
     *     {@code Username and password (separated)}
     */
    public static Localizable _UsernamePasswordMultiBinding_username_and_password() {
        return new Localizable(holder, "UsernamePasswordMultiBinding.username_and_password");
    }

    /**
     * Key {@code FileBinding.secret_file}: {@code Secret file}.
     * 
     * @return
     *     {@code Secret file}
     */
    public static String FileBinding_secret_file() {
        return holder.format("FileBinding.secret_file");
    }

    /**
     * Key {@code FileBinding.secret_file}: {@code Secret file}.
     * 
     * @return
     *     {@code Secret file}
     */
    public static Localizable _FileBinding_secret_file() {
        return new Localizable(holder, "FileBinding.secret_file");
    }

    /**
     * Key {@code ZipFileBinding.secret_zip_file}: {@code Secret ZIP file}.
     * 
     * @return
     *     {@code Secret ZIP file}
     */
    public static String ZipFileBinding_secret_zip_file() {
        return holder.format("ZipFileBinding.secret_zip_file");
    }

    /**
     * Key {@code ZipFileBinding.secret_zip_file}: {@code Secret ZIP file}.
     * 
     * @return
     *     {@code Secret ZIP file}
     */
    public static Localizable _ZipFileBinding_secret_zip_file() {
        return new Localizable(holder, "ZipFileBinding.secret_zip_file");
    }

    /**
     * Key {@code SSHUserPrivateKeyBinding.ssh_user_private_key}: {@code SSH
     * User Private Key}.
     * 
     * @return
     *     {@code SSH User Private Key}
     */
    public static String SSHUserPrivateKeyBinding_ssh_user_private_key() {
        return holder.format("SSHUserPrivateKeyBinding.ssh_user_private_key");
    }

    /**
     * Key {@code SSHUserPrivateKeyBinding.ssh_user_private_key}: {@code SSH
     * User Private Key}.
     * 
     * @return
     *     {@code SSH User Private Key}
     */
    public static Localizable _SSHUserPrivateKeyBinding_ssh_user_private_key() {
        return new Localizable(holder, "SSHUserPrivateKeyBinding.ssh_user_private_key");
    }

    /**
     * Key {@code UsernamePasswordBinding.username_and_password}: {@code
     * Username and password (conjoined)}.
     * 
     * @return
     *     {@code Username and password (conjoined)}
     */
    public static String UsernamePasswordBinding_username_and_password() {
        return holder.format("UsernamePasswordBinding.username_and_password");
    }

    /**
     * Key {@code UsernamePasswordBinding.username_and_password}: {@code
     * Username and password (conjoined)}.
     * 
     * @return
     *     {@code Username and password (conjoined)}
     */
    public static Localizable _UsernamePasswordBinding_username_and_password() {
        return new Localizable(holder, "UsernamePasswordBinding.username_and_password");
    }

    /**
     * Key {@code CertificateMultiBinding.certificate_keystore}: {@code
     * Certificate}.
     * 
     * @return
     *     {@code Certificate}
     */
    public static String CertificateMultiBinding_certificate_keystore() {
        return holder.format("CertificateMultiBinding.certificate_keystore");
    }

    /**
     * Key {@code CertificateMultiBinding.certificate_keystore}: {@code
     * Certificate}.
     * 
     * @return
     *     {@code Certificate}
     */
    public static Localizable _CertificateMultiBinding_certificate_keystore() {
        return new Localizable(holder, "CertificateMultiBinding.certificate_keystore");
    }

    /**
     * Key {@code SecretBuildWrapper.use_secret_text_s_or_file_s_}: {@code
     * Use secret text(s) or file(s)}.
     * 
     * @return
     *     {@code Use secret text(s) or file(s)}
     */
    public static String SecretBuildWrapper_use_secret_text_s_or_file_s_() {
        return holder.format("SecretBuildWrapper.use_secret_text_s_or_file_s_");
    }

    /**
     * Key {@code SecretBuildWrapper.use_secret_text_s_or_file_s_}: {@code
     * Use secret text(s) or file(s)}.
     * 
     * @return
     *     {@code Use secret text(s) or file(s)}
     */
    public static Localizable _SecretBuildWrapper_use_secret_text_s_or_file_s_() {
        return new Localizable(holder, "SecretBuildWrapper.use_secret_text_s_or_file_s_");
    }

    /**
     * Key {@code StringBinding.secret_text}: {@code Secret text}.
     * 
     * @return
     *     {@code Secret text}
     */
    public static String StringBinding_secret_text() {
        return holder.format("StringBinding.secret_text");
    }

    /**
     * Key {@code StringBinding.secret_text}: {@code Secret text}.
     * 
     * @return
     *     {@code Secret text}
     */
    public static Localizable _StringBinding_secret_text() {
        return new Localizable(holder, "StringBinding.secret_text");
    }

    /**
     * Key {@code ZipFileBinding.NoSuchCredentials}: {@code No such
     * credentials}.
     * 
     * @return
     *     {@code No such credentials}
     */
    public static String ZipFileBinding_NoSuchCredentials() {
        return holder.format("ZipFileBinding.NoSuchCredentials");
    }

    /**
     * Key {@code ZipFileBinding.NoSuchCredentials}: {@code No such
     * credentials}.
     * 
     * @return
     *     {@code No such credentials}
     */
    public static Localizable _ZipFileBinding_NoSuchCredentials() {
        return new Localizable(holder, "ZipFileBinding.NoSuchCredentials");
    }

    /**
     * Key {@code ZipFileBinding.CouldNotVerifyFileFormat}: {@code Could not
     * verify file format}.
     * 
     * @return
     *     {@code Could not verify file format}
     */
    public static String ZipFileBinding_CouldNotVerifyFileFormat() {
        return holder.format("ZipFileBinding.CouldNotVerifyFileFormat");
    }

    /**
     * Key {@code ZipFileBinding.CouldNotVerifyFileFormat}: {@code Could not
     * verify file format}.
     * 
     * @return
     *     {@code Could not verify file format}
     */
    public static Localizable _ZipFileBinding_CouldNotVerifyFileFormat() {
        return new Localizable(holder, "ZipFileBinding.CouldNotVerifyFileFormat");
    }

}
